# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class GetDiagnosticCategoriesResult:
    """
    A collection of values returned by getDiagnosticCategories.
    """
    def __init__(__self__, logs=None, metrics=None, resource_id=None, id=None):
        if logs and not isinstance(logs, list):
            raise TypeError("Expected argument 'logs' to be a list")
        __self__.logs = logs
        """
        A list of the Log Categories supported for this Resource.
        """
        if metrics and not isinstance(metrics, list):
            raise TypeError("Expected argument 'metrics' to be a list")
        __self__.metrics = metrics
        """
        A list of the Metric Categories supported for this Resource.
        """
        if resource_id and not isinstance(resource_id, str):
            raise TypeError("Expected argument 'resource_id' to be a str")
        __self__.resource_id = resource_id
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        id is the provider-assigned unique ID for this managed resource.
        """
class AwaitableGetDiagnosticCategoriesResult(GetDiagnosticCategoriesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDiagnosticCategoriesResult(
            logs=self.logs,
            metrics=self.metrics,
            resource_id=self.resource_id,
            id=self.id)

def get_diagnostic_categories(resource_id=None,opts=None):
    """
    Use this data source to access information about the Monitor Diagnostics Categories supported by an existing Resource.
    
    :param str resource_id: The ID of an existing Resource which Monitor Diagnostics Categories should be retrieved for.

    > This content is derived from https://github.com/terraform-providers/terraform-provider-azurerm/blob/master/website/docs/d/monitor_diagnostic_categories.html.markdown.
    """
    __args__ = dict()

    __args__['resourceId'] = resource_id
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('azure:monitoring/getDiagnosticCategories:getDiagnosticCategories', __args__, opts=opts).value

    return AwaitableGetDiagnosticCategoriesResult(
        logs=__ret__.get('logs'),
        metrics=__ret__.get('metrics'),
        resource_id=__ret__.get('resourceId'),
        id=__ret__.get('id'))
