# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class LinkService(pulumi.CustomResource):
    alias: pulumi.Output[str]
    """
    The alias is a globally unique name for your private link service which Azure generates for you. Your can use this alias to request a connection to your private link service.
    """
    auto_approval_subscription_ids: pulumi.Output[list]
    """
    A list of subscription globally unique identifiers(GUID) that will be automatically be able to use this service.
    """
    load_balancer_frontend_ip_configuration_ids: pulumi.Output[list]
    """
    A list of Standard Load Balancer(SLB) resource IDs. The Private Link service is tied to the frontend IP address of a SLB. All traffic destined for the private link service will reach the frontend of the SLB. You can configure SLB rules to direct this traffic to appropriate backend pools where your applications are running.
    """
    location: pulumi.Output[str]
    """
    Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
    """
    name: pulumi.Output[str]
    """
    The name of the private link service. Changing this forces a new resource to be created.
    """
    nat_ip_configurations: pulumi.Output[list]
    """
    A `nat_ip_configuration` block as defined below.
    
      * `name` (`str`) - The name of the private link service. Changing this forces a new resource to be created.
      * `primary` (`bool`)
      * `private_ip_address` (`str`)
      * `privateIpAddressVersion` (`str`)
      * `subnet_id` (`str`)
    """
    network_interface_ids: pulumi.Output[list]
    resource_group_name: pulumi.Output[str]
    """
    The name of the resource group in which the private link service resides. Changing this forces a new resource to be created.
    """
    tags: pulumi.Output[dict]
    """
    A mapping of tags to assign to the resource. Changing this forces a new resource to be created.
    """
    visibility_subscription_ids: pulumi.Output[list]
    """
    A list of subscription globally unique identifiers(GUID) that will be able to see this service. If left undefined all Azure subscriptions will be able to see this service.
    """
    def __init__(__self__, resource_name, opts=None, auto_approval_subscription_ids=None, load_balancer_frontend_ip_configuration_ids=None, location=None, name=None, nat_ip_configurations=None, resource_group_name=None, tags=None, visibility_subscription_ids=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages an Azure Private Link Service.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] auto_approval_subscription_ids: A list of subscription globally unique identifiers(GUID) that will be automatically be able to use this service.
        :param pulumi.Input[list] load_balancer_frontend_ip_configuration_ids: A list of Standard Load Balancer(SLB) resource IDs. The Private Link service is tied to the frontend IP address of a SLB. All traffic destined for the private link service will reach the frontend of the SLB. You can configure SLB rules to direct this traffic to appropriate backend pools where your applications are running.
        :param pulumi.Input[str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: The name of the private link service. Changing this forces a new resource to be created.
        :param pulumi.Input[list] nat_ip_configurations: A `nat_ip_configuration` block as defined below.
        :param pulumi.Input[str] resource_group_name: The name of the resource group in which the private link service resides. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the resource. Changing this forces a new resource to be created.
        :param pulumi.Input[list] visibility_subscription_ids: A list of subscription globally unique identifiers(GUID) that will be able to see this service. If left undefined all Azure subscriptions will be able to see this service.
        
        The **nat_ip_configurations** object supports the following:
        
          * `name` (`pulumi.Input[str]`) - The name of the private link service. Changing this forces a new resource to be created.
          * `primary` (`pulumi.Input[bool]`)
          * `private_ip_address` (`pulumi.Input[str]`)
          * `privateIpAddressVersion` (`pulumi.Input[str]`)
          * `subnet_id` (`pulumi.Input[str]`)

        > This content is derived from https://github.com/terraform-providers/terraform-provider-azurerm/blob/master/website/docs/r/private_link_service.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['auto_approval_subscription_ids'] = auto_approval_subscription_ids
            if load_balancer_frontend_ip_configuration_ids is None:
                raise TypeError("Missing required property 'load_balancer_frontend_ip_configuration_ids'")
            __props__['load_balancer_frontend_ip_configuration_ids'] = load_balancer_frontend_ip_configuration_ids
            __props__['location'] = location
            __props__['name'] = name
            if nat_ip_configurations is None:
                raise TypeError("Missing required property 'nat_ip_configurations'")
            __props__['nat_ip_configurations'] = nat_ip_configurations
            if resource_group_name is None:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__['resource_group_name'] = resource_group_name
            __props__['tags'] = tags
            __props__['visibility_subscription_ids'] = visibility_subscription_ids
            __props__['alias'] = None
            __props__['network_interface_ids'] = None
        super(LinkService, __self__).__init__(
            'azure:privatedns/linkService:LinkService',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, alias=None, auto_approval_subscription_ids=None, load_balancer_frontend_ip_configuration_ids=None, location=None, name=None, nat_ip_configurations=None, network_interface_ids=None, resource_group_name=None, tags=None, visibility_subscription_ids=None):
        """
        Get an existing LinkService resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] alias: The alias is a globally unique name for your private link service which Azure generates for you. Your can use this alias to request a connection to your private link service.
        :param pulumi.Input[list] auto_approval_subscription_ids: A list of subscription globally unique identifiers(GUID) that will be automatically be able to use this service.
        :param pulumi.Input[list] load_balancer_frontend_ip_configuration_ids: A list of Standard Load Balancer(SLB) resource IDs. The Private Link service is tied to the frontend IP address of a SLB. All traffic destined for the private link service will reach the frontend of the SLB. You can configure SLB rules to direct this traffic to appropriate backend pools where your applications are running.
        :param pulumi.Input[str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: The name of the private link service. Changing this forces a new resource to be created.
        :param pulumi.Input[list] nat_ip_configurations: A `nat_ip_configuration` block as defined below.
        :param pulumi.Input[str] resource_group_name: The name of the resource group in which the private link service resides. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the resource. Changing this forces a new resource to be created.
        :param pulumi.Input[list] visibility_subscription_ids: A list of subscription globally unique identifiers(GUID) that will be able to see this service. If left undefined all Azure subscriptions will be able to see this service.
        
        The **nat_ip_configurations** object supports the following:
        
          * `name` (`pulumi.Input[str]`) - The name of the private link service. Changing this forces a new resource to be created.
          * `primary` (`pulumi.Input[bool]`)
          * `private_ip_address` (`pulumi.Input[str]`)
          * `privateIpAddressVersion` (`pulumi.Input[str]`)
          * `subnet_id` (`pulumi.Input[str]`)

        > This content is derived from https://github.com/terraform-providers/terraform-provider-azurerm/blob/master/website/docs/r/private_link_service.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["alias"] = alias
        __props__["auto_approval_subscription_ids"] = auto_approval_subscription_ids
        __props__["load_balancer_frontend_ip_configuration_ids"] = load_balancer_frontend_ip_configuration_ids
        __props__["location"] = location
        __props__["name"] = name
        __props__["nat_ip_configurations"] = nat_ip_configurations
        __props__["network_interface_ids"] = network_interface_ids
        __props__["resource_group_name"] = resource_group_name
        __props__["tags"] = tags
        __props__["visibility_subscription_ids"] = visibility_subscription_ids
        return LinkService(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop

